# Tailwind CSS Hero Pattern

A simple tailwind plugin to display [Hero Patterns](http://www.heropatterns.com/) by [@steveschoger](https://twitter.com/steveschoger).

## Installation

`yarn add tailwindcss-hero-patterns`

or

`npm i tailwindcss-hero-patterns`

## Usage

### Simple

Just include the plugin:

```
    plugins: [
    require('tailwindcss-hero-patterns'),
  ],
```

And start using it:

```html
<div class="flex m-2 relative w-40 h-40 sm:pb-0 sm:w-48 sm:h-48 bg-red-500">
  <div
    class="bg-repeat w-full h-full text-primary-100 heropattern-jigsaw-red-100"
  >
    <div class="text-sm inline">heropattern-jigsaw-red-500</div>
  </div>
</div>
```

### Advanced Usage

#### Select only some templates

[Hero Patterns](http://www.heropatterns.com/) contains more than 80 patterns, so the generated CSS could be really heavy (at least 24Mo).

A good practice is to only import the desired patterns:

```
const heropatterns = require("tailwindcss-hero-patterns/patterns");

module.exports = {
  theme: {
    heropatterns: {
      architect: patterns.architect,
    },
    extend: {
        ...
    },
  },
};
```

#### Add your own template

Prefined patterns comes from [Hero Patterns](http://www.heropatterns.com/), but you can add your own:

```
module.exports = {
  theme: {
    extend: {
      heropatterns: {
        circles: `url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' width='100%25' height='100%25'%3E%3Cpattern id='pattern-circles' x='0' y='0' width='40' height='40' patternUnits='userSpaceOnUse'%3E%3Ccircle cx='20' cy='20' r='20'%3E%3C/circle%3E%3C/pattern%3E%3Crect x='0' y='0' width='100%25' height='100%25' fill='url(%23pattern-circles)'%3E%3C/rect%3E%3C/svg%3E");`,
      },
    },
  },
};
```
